#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-wireplumber
version:                0.5.14.2
visibility:             public
id:                     gi-wireplumber-0.5.14.2-FCiCgrF4IaGGpQOyWj29fe
key:                    gi-wireplumber-0.5.14.2-FCiCgrF4IaGGpQOyWj29fe
license:                LGPL-2.1-only
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/taffybar/taffybar
synopsis:               WirePlumber bindings
description:            WirePlumber bindings autogenerated by haskell-gi.
category:               Bindings
abi:                    26430dc28eb2096886b39d7e43377998
exposed:                True
exposed-modules:
    GI.Wp GI.Wp.Callbacks GI.Wp.Config GI.Wp.Constants GI.Wp.Enums
    GI.Wp.Flags GI.Wp.Functions GI.Wp.Interfaces
    GI.Wp.Interfaces.ComponentLoader GI.Wp.Interfaces.PipewireObject
    GI.Wp.Interfaces.SiAcquisition GI.Wp.Interfaces.SiAdapter
    GI.Wp.Interfaces.SiLink GI.Wp.Interfaces.SiLinkable GI.Wp.Objects
    GI.Wp.Objects.AsyncEventHook GI.Wp.Objects.Client
    GI.Wp.Objects.Conf GI.Wp.Objects.Core GI.Wp.Objects.Device
    GI.Wp.Objects.DynamicRules GI.Wp.Objects.EventDispatcher
    GI.Wp.Objects.EventHook GI.Wp.Objects.Factory
    GI.Wp.Objects.FeatureActivationTransition GI.Wp.Objects.GlobalProxy
    GI.Wp.Objects.ImplMetadata GI.Wp.Objects.ImplModule
    GI.Wp.Objects.ImplNode GI.Wp.Objects.InterestEventHook
    GI.Wp.Objects.Link GI.Wp.Objects.Metadata GI.Wp.Objects.Node
    GI.Wp.Objects.Object GI.Wp.Objects.ObjectManager
    GI.Wp.Objects.PermissionManager GI.Wp.Objects.Plugin
    GI.Wp.Objects.Port GI.Wp.Objects.Proxy GI.Wp.Objects.SessionItem
    GI.Wp.Objects.Settings GI.Wp.Objects.SiFactory
    GI.Wp.Objects.SimpleEventHook GI.Wp.Objects.SpaDevice
    GI.Wp.Objects.SpaType GI.Wp.Objects.State
    GI.Wp.Objects.StateMetadata GI.Wp.Objects.Transition GI.Wp.Structs
    GI.Wp.Structs.Event GI.Wp.Structs.Global GI.Wp.Structs.Iterator
    GI.Wp.Structs.IteratorMethods GI.Wp.Structs.LogTopic
    GI.Wp.Structs.MetadataItem GI.Wp.Structs.ObjectInterest
    GI.Wp.Structs.ProcInfo GI.Wp.Structs.Properties
    GI.Wp.Structs.PropertiesItem GI.Wp.Structs.SettingsItem
    GI.Wp.Structs.SettingsSpec GI.Wp.Structs.SpaJson
    GI.Wp.Structs.SpaJsonBuilder GI.Wp.Structs.SpaJsonParser
    GI.Wp.Structs.SpaPod GI.Wp.Structs.SpaPodBuilder
    GI.Wp.Structs.SpaPodParser

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-wireplumber-0.5.14.2
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-wireplumber-0.5.14.2 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-wireplumber-0.5.14.2 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-wireplumber
hs-libraries:           HSgi-wireplumber-0.5.14.2-FCiCgrF4IaGGpQOyWj29fe
extra-libraries:        wireplumber-0.5 gio-2.0 gobject-2.0 glib-2.0
extra-libraries-static:
    wireplumber-0.5 gio-2.0 gobject-2.0 ffi z mount blkid systemd
    gmodule-2.0 glib-2.0 atomic m sysprof-capture-4 pcre2-8 pthread
    pipewire-0.3

include-dirs:
    /usr/include/wireplumber-0.5 /usr/include /usr/include/libmount
    /usr/include/blkid /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/pipewire-0.3
    /usr/include/spa-0.2

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-gio-2.0.38-FKXAOomjvdtRwYgeC5iW0
    gi-glib-2.0.30-IbMceUkbPFbAzdIeE6ROJx
    gi-gobject-2.0.31-98nt0liAWOGCQ6jtwFHBqO
    haskell-gi-0.26.17-8JFBf5L4fuwFdV2u3KLSL6
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-gi-wireplumber/html/gi-wireplumber.haddock

haddock-html:           /usr/share/doc/haskell-gi-wireplumber/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

